checkRequire("Lua_HeroAwakenSkillIcon");
checkRequire("Lua_HeroAttributeItem");
Lua_HeroAwakenPanel = class("Lua_HeroAwakenPanel", Lua_DisplayObject);
function Lua_HeroAwakenPanel:ctor(p)
	self:superCall("ctor", p, "HeroAwakenPanel_skin");
end

function Lua_HeroAwakenPanel:buildShowItem()
	self:superCall("buildShowItem");

	self.infoObject:SetActive(false);
	self.awakenIcon:addClickFuntion(self, self.onAwakeChoose);
	self.checkHelp:addClickFuntion(self, self.onCheckHelp);
	self.btnUpgrade:addClickFuntion(self, self.onBtnUpgradeClick);

	self:addLuaEvent("HERO_AWAKEN_SKILL_SWITCH", self, self.onSkillSwitch);
end

function Lua_HeroAwakenPanel:dispose()
	if self.skillArr ~= nil then
		self.skillArr:dispose();
		self.skillArr = nil;
	end
	self.skillDic = nil;
	if self.attrArr ~= nil then
		self.attrArr:dispose();
		self.attrArr:clear();
		self.attrArr = nil;
	end
	if self.costArr ~= nil then
		self.costArr:dispose();
		self.costArr:clear();
		self.costArr = nil;
	end
	self.winParam = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_HeroAwakenPanel:updateHeroPanelInfo(data)
	self.data = data;

	if data.awaken_id == nil or data.awaken_id <= 0 then
		self.awakenIcon:setAltas("common_altas_3", "ui_sd_button_001_n");
		self.prompt.text = "消耗英雄材料和觉醒石为英雄觉醒";
		self.infoObject:SetActive(false);
		self:showSkillItem(0);
	else
		self.prompt.text = "";
		self.infoObject:SetActive(true);

		local maxLv = DataCenter.heroUtil.awaken_max_level;
		local config = DataCenter.heroUtil:getAwakenConfig(data.awaken_id);
		local awakenVo = DataCenter.heroUtil:getAwakenTypeVo(config.type);
		self.awakenIcon:setAltas(awakenVo.atlas, awakenVo.sprite);
		self.awakeLevel.text = LanUtil.formateStr("等级: {1}/{2}", tostring(config.level), tostring(maxLv));

		self:showSkillItem(config.level);
		if data.awaken_info ~= nil then
			local obj;
			for i = 1, #data.awaken_info do
				obj = data.awaken_info[i];
				if self.skillDic[tonumber(obj.key)] ~= nil then
					self.skillDic[tonumber(obj.key)]:setSkill(tonumber(obj.value), tonumber(obj.sub));
				end
			end
		end

		self:showAttrItem(config.prop_add);
		if config.level >= maxLv then
			self:showCostItem(nil);
			self.promptText.text = "已满级";
			self.btnUpgrade:setEnable(false);
		else
			self:showCostItem(config.resource_material);
			self.promptText.text = "";
			self.btnUpgrade:setEnable(true);
		end
	end
end

function Lua_HeroAwakenPanel:showSkillItem(level)
	if self.skillArr == nil then
		self.skillArr = Array();
		self.skillDic = {};
	end
	local list = DataCenter.heroUtil.awaken_column_unlock;
	local item;
	local len = self.skillArr:getSize();
	local dataLen = #list;
	local maxLen = dataLen > len and dataLen or len;
	for i = 1, maxLen do
		item = self.skillArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_HeroAwakenSkillIcon.new(self.content);
				self.skillArr:add(item);
			else
				item:setEnable(true);
			end
			item:setLocation(-260 + i * 160, -285, 0);
			item:setClickCallBack(self, self.onSkillClick);
			item:setData(list[i][1], list[i][2], level);
			self.skillDic[item.columnIdx] = item;
		end
	end
end

function Lua_HeroAwakenPanel:onSkillClick(value, columnIdx, skillIdx, skillId)
	if self.winParam == nil then
		self.winParam = { columnIdx = columnIdx, skillIdx = skillIdx, skillId = skillId, heroUId = self.data.unique_id, awakenId = self.data.awaken_id };
	else
		self.winParam.columnIdx = columnIdx;
		self.winParam.skillIdx = skillIdx;
		self.winParam.skillId = skillId;
		self.winParam.heroUId = self.data.unique_id;
		self.winParam.awakenId = self.data.awaken_id;
	end

	if value == 1 then -- 选择
		Lua_WindowUtil.openWin("Lua_HeroAwakenSkillSelectWindow", Lua_WinParam.ACTION_OPEN, self.winParam);
	elseif value == 2 then -- 解锁
		Lua_WindowUtil.openWin("Lua_HeroAwakenSkillUnlockWindow", Lua_WinParam.ACTION_OPEN, self.winParam);
	elseif value == 3 then -- 详情
		Lua_WindowUtil.openWin("Lua_HeroAwakenSkillDetailsWindow", Lua_WinParam.ACTION_OPEN, self.winParam);
	end
end

function Lua_HeroAwakenPanel:showAttrItem(data)
	if self.attrArr == nil then
		self.attrArr = Array();
	end
	local arr = DataCenter.attributesUtil:getAttrArrByConfig(data);
	local dataLen = arr:getSize();
	local len = self.attrArr:getSize();
	local maxLen = dataLen > len and dataLen or len;
	local item;
	for i = 1, maxLen do
		item = self.attrArr[i];
		if i > dataLen then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_HeroAttributeItem.new(self.infoObject);
				self.attrArr:add(item);
			else
				item:setEnable(true);
			end
			item:setLocation(-150 + (i -1) * 140, 315, 0);
			item:setData(arr[i]);
		end
	end
end

function Lua_HeroAwakenPanel:showCostItem(data)
	if data == nil then
		if self.costArr ~= nil then
			for i = 1, self.costArr:getSize() do
				self.costArr[i]:setEnable(false);
			end
		end
	else
		if self.costArr == nil then
			self.costArr = Array();
		end

		local len = #data - self.costArr:getSize();
		while (len > 0) do
			item = Lua_ConsumeIconItem.new(self.infoObject);
			self.costArr:add(item);
			len = len - 1;
		end

		while (len < 0) do
			item = self.costArr:remove(1);
			item:dispose();
			len = len + 1;
		end

		len = self.costArr:getSize();
		local space = 200;
		local w;
		local posX;
		for i = 1, len do
			item = self.costArr[i];
			item:setEnable(true);
			item:setData(data[i]);

			w = -(space * len) / 2 + space / 2;
			posX = ((i - 1) % len) * space + w;
			item:setLocation(posX, 220, 0);
		end
	end
end

function Lua_HeroAwakenPanel:onSkillSwitch(data)
	if self.winParam == nil then
		self.winParam = { columnIdx = columnIdx, skillIdx = skillIdx, skillId = skillId, heroUId = self.data.unique_id, awakenId = self.data.awaken_id };
	else
		self.winParam.columnIdx = columnIdx;
		self.winParam.skillIdx = skillIdx;
		self.winParam.skillId = skillId;
		self.winParam.heroUId = self.data.unique_id;
		self.winParam.awakenId = self.data.awaken_id;
	end
	Lua_WindowUtil.openWin("Lua_HeroAwakenSkillSwitchWindow", Lua_WinParam.ACTION_OPEN, self.winParam);
end

function Lua_HeroAwakenPanel:onAwakeChoose(go)
	Lua_WindowUtil.openWin("Lua_HeroAwakenWindow", Lua_WinParam.ACTION_OPEN, self.data);
end

function Lua_HeroAwakenPanel:onCheckHelp(go)
	local tipsData = { des = LanUtil.getValue(129002), posX = 80, posY = 462 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_HeroAwakenPanel:onBtnUpgradeClick(go)
	local config = DataCenter.heroUtil:getAwakenConfig(self.data.awaken_id);
	local costId = DataCenter.packData:checkConsumeEnough(config.resource_material);
	if costId == nil then
		Lua_ProxyManager.getProxy("Lua_HeroProxy"):sUpgradeAwaken(self.data.unique_id);
	else
		DataCenter.packUtil:openPathWindow(costId, false);
	end
end