Lua_HeroFashionPanel = class("Lua_HeroFashionPanel", Lua_DisplayObject)
function Lua_HeroFashionPanel:ctor(p)
    self:superCall("ctor", p,"HeroFashionPanel_skin");
end

function Lua_HeroFashionPanel:buildShowItem()
	self:superCall("buildShowItem");

    self:addLuaEvent("UPDATE_HERO_FASHION_INFO", self, self.updateShowInfo);
    self:addLuaEvent("HERO_FASHION_ACTIVATE", self, self.onFashionActivate);

    self.itemList = Lua_CenterList.new(self.content, 600, 299, Lua_AxisDefine.Horizontal);
    self.itemList:setRectAnchor(7);
    self.itemList:setLocation(0, 378, 0);
    self.itemList.type = 2;
    self.itemList:setCellList(Lua_HeroFashionItem, 186, 248);
    self.itemList:setTransformData(-30, 8.45, 0.84, 1);
    self.itemList:setShowCount(3);
    self.itemList:setCallBack(self, self.onCallBack);

    self.checkAttr:addClickFuntion(self, self.onCheckAttr);
    self.btnFunc:addClickFuntion(self, self.onFuncClick);
end

function Lua_HeroFashionPanel:dispose()
    if self.itemList then
        self.itemList:dispose();
        self.itemList = nil;
    end
    self.itemArr = nil;
    if self.curPropItem then
        self.curPropItem:dispose();
        self.curPropItem = nil;
    end
    if self.allPropItem then
        self.allPropItem:dispose();
        self.allPropItem = nil;
    end
    if self.redPoint then
        self.redPoint:dispose();
        self.redPoint = nil;
    end
    self.data = nil;
    self.isAtlas = nil;
    self.fashionVo = nil;
    DataCenter.winTweenManager:removeWinTween(self.tweenName);
    self:superCall("dispose");
end

function Lua_HeroFashionPanel:updateHeroPanelInfo(data, isAtlas, showData)
    self.data = data;
    self.isAtlas = isAtlas;

    self.checkAttr:setEnable(not isAtlas);
    self.line:setEnable(not isAtlas);
    self.btnFunc:setEnable(not isAtlas);
    if isAtlas then
        self.itemList:setLocation(0, 300, 0);
    else
        self.itemList:setLocation(0, 378, 0);
    end

    self.fashionVo = nil;
    local selectFashionId = data.clothesId;
    if showData and showData.clothesId then
        selectFashionId = showData.clothesId;
        showData.clothesId = nil;
    end
    DataCenter.heroFashionData.curFashionId = data.clothesId;

    self.itemArr = DataCenter.heroFashionData:getHeroFashionList(data.id);
    local index;
    for i = 1, self.itemArr:getSize() do
        if self.itemArr[i] == selectFashionId then
            index = i;
        end
    end
    self.itemList.customParam = isAtlas;
    self.itemList:setArrayData(self.itemArr);
    self.itemList:moveToIndex(index, true);
    self.itemList:setSelectClick(index);

    if self.tag_uid ~= data.unique_id then
        self.tag_uid = data.unique_id
        if self.tweenName ~= nil then
            DataCenter.winTweenManager:removeWinTween(self.tweenName);
        end
        self.tweenName = DataCenter.winTweenManager:createWinTween(self.content.name, self.content.transform);
    end
end

function Lua_HeroFashionPanel:onCallBack()
    local index = self.itemList.curIndex;
    local data = self.itemArr[index];
    local vo = DataCenter.heroFashionData:getHeroFashionVo(data);
    if vo == nil then
        vo = Lua_HeroConfigData.getConfig(data);
    end
    self:onFashionSelected(vo);
end

function Lua_HeroFashionPanel:onFashionSelected(data)
    if self.fashionVo == data then
        return;
    end
    self.fashionVo = data;

    if not strIsNullOrEmpty(data.curPropStr) then
        if self.curPropItem == nil then
            self.curPropItem = Lua_HeroFashionPropItem.new(self.content);
            self.curPropItem:setSiblingIndex(0);
            self.curPropItem:setRectAnchor(7);
            self.curPropItem:setLocation(-207, 601, 0);
        end
        self.curPropItem:setEnable(true);
        self.curPropItem:setData(126500, data.curPropStr);
    else
        if self.curPropItem then
            self.curPropItem:setEnable(false);
        end
    end

    if not strIsNullOrEmpty(data.allPropStr) then
        if self.allPropItem == nil then
            self.allPropItem = Lua_HeroFashionPropItem.new(self.content);
            self.allPropItem:setSiblingIndex(1);
            self.allPropItem:setRectAnchor(7);
        end
        if strIsNullOrEmpty(data.curPropStr) then
            self.allPropItem:setLocation(-207, 601, 0);
        else
            self.allPropItem:setLocation(-207, 490, 0);
        end
        self.allPropItem:setEnable(true);
        self.allPropItem:setData(126501, data.allPropStr);
    else
        if self.allPropItem then
            self.allPropItem:setEnable(false);
        end
    end

    Lua_MsgUtil.callFunc("UPDATE_HERO_MODEL", data);
    self:updateShowInfo();
end

function Lua_HeroFashionPanel:updateShowInfo()
    self.itemList:updateShowList();

    if self.fashionVo == nil or self.isAtlas then
        self.btnFunc:setEnable(false);
        self:showRedPoint(false);
    else
        if self.fashionVo.isSkin then
            self.btnFunc:setEnable(self.fashionVo.id ~= self.data.clothesId);
            if self.fashionVo.isActivate then
                self.btnFunc:setLangValue(126513);
            elseif self.fashionVo.activateItem > 0 then
                self.btnFunc:setLangValue(126506);
            else
                self.btnFunc:setLangValue(126507);
            end
        else
            self.btnFunc:setEnable(self.data.clothesId ~= 0);
            self.btnFunc:setLangValue(126513);
        end
        self:showRedPoint(self.fashionVo.redPointState);
    end

    self.allAttrStr = DataCenter.heroFashionData:getFashionAttrStr();
    self.checkAttr:setEnable(not self.isAtlas and not strIsNullOrEmpty(self.allAttrStr));
end

function Lua_HeroFashionPanel:showRedPoint(bValue)
    if bValue then
        if self.redPoint == nil then
            self.redPoint = Lua_RedPointIcon.new(self.content);
            self.redPoint:setRectAnchor(7);
            self.redPoint:setLocation(100, 190, 0);
            self.redPoint:showRedPoint(true, true);
        end
        self.redPoint:setEnable(true);
    else
        if self.redPoint then
            self.redPoint:setEnable(false);
        end
    end
end

function Lua_HeroFashionPanel:onCheckAttr(go)
    local str;
    if self.fashionVo.isSkin and self.fashionVo.isActivate then
        local arr = DataCenter.attributesUtil:getAttrArrByDic(self.fashionVo.curProp);
        for i = 1, arr:getSize() do
            if i == 1 then
                str = LanUtil.formateStr(126503, arr[i].show_name, arr[i].showValue);
            else
                str = str.."\n"..LanUtil.formateStr(126503, arr[i].show_name, arr[i].showValue);
            end
        end
    end
    Lua_WindowUtil.openWin("Lua_HeroFashionAttrWindow", Lua_WinParam.ACTION_OPEN, { curAttrStr = str, allAttrStr = self.allAttrStr });
end

function Lua_HeroFashionPanel:onFuncClick(go)
    if self.fashionVo == nil then
        return;
    end
    if self.fashionVo.isSkin then
        if self.fashionVo.isActivate then
            Lua_ProxyManager.getProxy("Lua_HeroProxy"):sUseFashion(self.data.unique_id, self.fashionVo.id);
        else
            if self.fashionVo.activateItem > 0 then
                local arr = DataCenter.packData:getUnIdList(Lua_PackDefine.HERO_DRESSUP, self.fashionVo.itemSubType);
                if arr == nil or arr:getSize() <= 0 then
                    DataCenter.packUtil:openPathWindow(self.fashionVo.activateItem, false);
                else
                    Lua_WindowUtil.openWin("Lua_HeroFashionActivateWindow", Lua_WinParam.ACTION_OPEN, arr);
                end
            elseif self.fashionVo.activatePath > 0 then
                DataCenter.funcPathUtil:gotoFunction(self.fashionVo.activatePath, true);
            end
        end
    else
        Lua_ProxyManager.getProxy("Lua_HeroProxy"):sUseFashion(self.data.unique_id, 0);
    end
end

function Lua_HeroFashionPanel:onFashionActivate(data)
    local vo = DataCenter.packData:getItemVoByUnId(data);
    local arr = Array();
    arr:add(self.data.unique_id);
    Lua_ProxyManager.getProxy("Lua_PackProxy"):sUseItem(vo.pack_type, vo.unique_id, 1, arr);
    Lua_WindowUtil.openWin("Lua_HeroFashionActivateWindow", Lua_WinParam.ACTION_CLOSE);
end











Lua_HeroFashionItem = class("Lua_HeroFashionItem", Lua_CenterCell)
function Lua_HeroFashionItem:ctor(p)
    self:superCall("ctor", p, "HeroFashionItem_skin");
end

function Lua_HeroFashionItem:buildShowItem()
    self:superCall("buildShowItem");
end

function Lua_HeroFashionItem:dispose()
    self:stopTimer();
    self:superCall("dispose");
end

function Lua_HeroFashionItem:setCustomParam(customParam)
    self.isAtlas = customParam;
end

function Lua_HeroFashionItem:setData(data)
    self:stopTimer();
    self.data = DataCenter.heroFashionData:getHeroFashionVo(data);
    if self.data == nil then
        self.data = Lua_HeroConfigData.getConfig(data);
    end
    self.showImg:setUrl(self.data.skinPicUrl);
    self.nameText.text = self.data.name;
    self:updateData();
end

function Lua_HeroFashionItem:updateData()
    if self.data.isSkin then
        if self.data.isActivate then
            if self.data.tick == 0 then
                self.timeText:setLangValue(126508);
            else
                self:startTimer();
                self:onTimer();
            end
        else
            if self.data.type == 2 then
                self.timeText:setLangValue(126511);
            elseif self.data.type == 3 then
                self.timeText:setLangValue(126512);
            else
                self.timeText:setLangValue(126510);
            end
        end

        if self.isAtlas then
            self.useIcon:setEnable(false);
        else
            self.useIcon:setEnable(DataCenter.heroFashionData.curFashionId == self.data.id);
        end
    else
        self.timeText:setLangValue(126508);
        if self.isAtlas then
            self.useIcon:setEnable(false);
        else
            self.useIcon:setEnable(DataCenter.heroFashionData.curFashionId == 0);
        end
    end
end

function Lua_HeroFashionItem:startTimer()
    if self.bTimer ~= true then
        self.bTimer = true;
        self:addTimer("Lua_HeroFashionItem", 1, self, self.onTimer, nil, -1);
    end
end

function Lua_HeroFashionItem:stopTimer()
    if self.bTimer == true then
        self.bTimer = false;
        self:removeTimer(self, self.onTimer);
    end
end

function Lua_HeroFashionItem:onTimer()
    self.timeText.text = LanUtil.formateStr(126509, Lua_TimeTransform.transSeconds24(self.data.residueTime));
end

function Lua_HeroFashionItem:onSelectionChange(bSelected)
    self:superCall("onSelectionChange", bSelected);
    self.maskIcon:setEnable(not bSelected);
end









Lua_HeroFashionPropItem = class("Lua_HeroFashionPropItem", Lua_DisplayObject)
function Lua_HeroFashionPropItem:ctor(p)
    self:superCall("ctor", p, "HeroFashionPropItem_skin");
end

function Lua_HeroFashionPropItem:buildShowItem()
    self:superCall("buildShowItem");
end

function Lua_HeroFashionPropItem:setData(titleId, propStr)
    self.titleText:setLangValue(titleId);
    self.desText.text = propStr;
end