Lua_HeroGeniusActivateWindow = class("Lua_HeroGeniusActivateWindow", Lua_Window)
function Lua_HeroGeniusActivateWindow:ctor()
	self:superCall("ctor");
	
	self.windowName = "Lua_HeroGeniusActivateWindow";
	self.skinName = "HeroGeniusActivateWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_HeroGeniusActivateWindow:buildShowItem()
	self:superCall("buildShowItem");
	self:addLuaEvent("HERO_GENIUS_MATERIAL_SELECT", self, self.onMaterialSelected)

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setLocation(0, 161.5, 0);
	self.itemIcon:setShadow(true, "hero_genius_atlas", "xui_zxtt_button_5_n");

	self.btnCancel:addClickFuntion(self, self.hide);
	self.btnSure:addClickFuntion(self, self.onActivate);
end

function Lua_HeroGeniusActivateWindow:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	if self.itemList then
		self.itemList:dispose();
		self.itemList = nil;
	end
	DataCenter.heroMaterialData:dispose();
	self:superCall("dispose");
end

function Lua_HeroGeniusActivateWindow:showWin(param)
	self:superCall("showWin", param);

	DataCenter.heroMaterialData:init(param.heroUid);
	local data = DataCenter.heroGeniusData:getGeniusConfig(param.geniusId);
	self.condText.text = data.cond_des;
	self:updateConsume(data.cost_item[1]);

	if self.materialVo == nil then
		self.materialVo = DataCenter.heroMaterialData:createMaterialVo(1);
		self.materialVo:setData(data.hero_material[1]);
	end
	local arr = DataCenter.heroMaterialData:getHeroList(self.materialVo);
	if arr and arr:getSize() > 0 then
		if self.itemList == self.itemList then
			local width = Mathf.Ceil(124 * 0.84);
			self.itemList = Lua_DragList.new(self.content, width * 5 + 20 * 4, 200, Lua_AxisDefine.Vertical);
			self.itemList:setLocation(0, -118.5, 0);
			self.itemList:setListCell(Lua_HeroGeniusActivateItem, width, width, 5);
			self.itemList:setCellSpacing(20, 15);
		end
		self.itemList:setArrayData(arr);
	else
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, -118.5, 648, 119);
			self.noneIcon:setScale(0.8, 0.8, 1);

			self.noneText = UICreate.createLabel(self.content, nil, 0, -118.5, 100, 31, 30);
			self.noneText.pivotValue = 4;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.verticalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("938680");
			self.noneText:setLangValue(126095);
		end		
	end
end

function Lua_HeroGeniusActivateWindow:updateConsume(cost)
	local itemCfg = getConfig("item", cost[1]);
	self.costIcon:setAltas(itemCfg.atlas, itemCfg.sprite);
	local haveNum = DataCenter.packData:getItemCountById(itemCfg.id);
	if haveNum >= cost[2] then
		self.costId = nil;
		haveNum = numberTrans(haveNum);
	else
		self.costId = itemCfg.id;
		haveNum = Lua_ColorDefine.getColorStr("ED4C30", numberTrans(haveNum));
	end
	self.costText.text = LanUtil.formateStr(10044, haveNum, numberTrans(cost[2]));
	self.costText:resetSize();
	local width = 40 + self.costText.width;
	self.costBg:SetDimensions(width, 32);
	width = Mathf.Abs(width - 40) / 2;
	LuaUtil.setObjPos(self.costObject, 160 - width, -275, 0);
end

function Lua_HeroGeniusActivateWindow:onMaterialSelected(heroUnId)
	DataCenter.heroMaterialData:removeHeroMaterial(self.materialVo.index, self.heroUnId);
	DataCenter.heroMaterialData:addHeroMaterial(self.materialVo.index, heroUnId);
	self.heroUnId = heroUnId;
	if heroUnId and heroUnId > 0 then
		local heroVo = DataCenter.heroData:getItemByUniqueId(heroUnId);
		self.itemIcon:setData(heroVo);
		self.itemIcon:setShadow(false);
	else
		self.itemIcon:setData(nil);
		self.itemIcon:setShadow(true, "hero_genius_atlas", "xui_zxtt_button_5_n");
	end
	self.itemList:updateShowList();
end

function Lua_HeroGeniusActivateWindow:onActivate(go)
	if self.costId then
		DataCenter.packUtil:openPathWindow(self.costId);
	else
		if self.materialVo.bEnough then
			Lua_ProxyManager.getProxy("Lua_HeroProxy"):sGeniusActivate(self.showData.heroUid, DataCenter.heroMaterialData.selectedDic);
			self:hide();
		else
			OperateAlert.showLangValue(126094)
		end
	end
end










Lua_HeroGeniusActivateItem = class("Lua_HeroGeniusActivateItem", Lua_ListCell)
function Lua_HeroGeniusActivateItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_HeroGeniusActivateItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = Lua_ItemIcon.new(self.content);
	self.itemIcon:setScale(0.84, 0.84, 1);
end

function Lua_HeroGeniusActivateItem:dispose()
	if self.itemIcon then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self.heroVo = nil;
	self:superCall("dispose");
end

function Lua_HeroGeniusActivateItem:setData(data)
	self.data = data;
	self.heroVo = DataCenter.heroData:getItemByUniqueId(data);
	self.itemIcon:setData(self.heroVo);
	self:updateData();
end

function Lua_HeroGeniusActivateItem:updateData()
	self.bSelected = DataCenter.heroMaterialData:checkHeroIsSelected(self.heroVo.unique_id)
	self.isDownLineup = DataCenter.heroMaterialData:checkIsDownLineup(self.heroVo.unique_id)
	if self.bSelected then
		self.itemIcon:setLock(false);
		self.itemIcon:setMask(false);
		self.itemIcon:setDrawMask(true);
	elseif self.heroVo.lock_state or (self.heroVo.isUpLineup and not self.isDownLineup) then
		self.itemIcon:setLock(true);
		self.itemIcon:setMask(true);
		self.itemIcon:setDrawMask(false);
	else
		self.itemIcon:setLock(false);
		self.itemIcon:setMask(false);
		self.itemIcon:setDrawMask(false);
	end
end

function Lua_HeroGeniusActivateItem:onPressClick()
	if self.heroVo.isUpLineup and not self.isDownLineup then
		self:showLineupTips();
		return;
	end

	if self.heroVo.lock_state then
		self:showUnlockTips();
		return;
	end

	if self.heroVo.bcore then
		self:showBcoreTips();
		return;
	end
	
	self:onSure();
end

function Lua_HeroGeniusActivateItem:showLineupTips()
	local tipData = { des = LanUtil.formateStr(126221, self.heroVo.upLineupName), btnType = 1, owner = self, sureFun = self.onHeroLineup };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_HeroGeniusActivateItem:onHeroLineup()
    local bDownLineup, showName = DataCenter.heroMaterialData:checkLineupStateAndNum(self.heroVo.unique_id);
    if bDownLineup then
        OperateAlert.showLangValue(126222);
        DataCenter.heroMaterialData:setDownLineup(self.heroVo.unique_id);
    else
        OperateAlert.show(LanUtil.formateStr(126223, showName));
        return;
    end

	if self.heroVo.lock_state then
		self:showUnlockTips();
		return;
	end

	if self.heroVo.bcore then
		self:showBcoreTips();
		return;
	end
	
	self:onSure();
end

function Lua_HeroGeniusActivateItem:showUnlockTips()
	local tipData = { des = LanUtil.getValue(126219), btnType = 1, owner = self, sureFun = self.onUnlock };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_HeroGeniusActivateItem:onUnlock()
	Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroLock(self.heroVo.unique_id, 0);

	if self.heroVo.bcore then
		self:showBcoreTips();
		return;
	end
	
	self:onSure();
end

function Lua_HeroGeniusActivateItem:showBcoreTips()
	local tipData = { des = LanUtil.getValue(126207), btnType = 1, owner = self, sureFun = self.onSure };
	Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_HeroGeniusActivateItem:onSure()
	Lua_MsgUtil.callFunc("HERO_GENIUS_MATERIAL_SELECT", self.heroVo.unique_id);
end