-- 英雄天赋
Lua_HeroGeniusWindow = class("Lua_HeroGeniusWindow", Lua_Window)
function Lua_HeroGeniusWindow:ctor()
	self:superCall("ctor");
	
	self.windowName = "Lua_HeroGeniusWindow";
	self.skinName = "HeroGeniusWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_HeroGeniusWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.geniusPos = {{-264, 351.5, 0.86}, {-84, 408, 0.86}, {66, 351.5, 0.86}, {255, 416.5, 1}};
	self.geniusItems = Array();

	self:addLuaEvent("UPDATE_ONE_HERO_INFO", self, self.updateShowInfo);
	self:addLuaEvent("HERO_GENIUS_ACTIVATE", self, self.showActivateEff);
	self:addLuaEvent("HERO_GENIUS_SKILL_SELECT", self, self.onSkillSelected);

	self.skillList = Lua_DragList.new(self.content, 630, 668, Lua_AxisDefine.Vertical);
	self.skillList:setLocation(0, -116, 0);
	self.skillList:setListCell(Lua_HeroGeniusSkillItem, 630, 167, 1);
	self.skillList.tweenId = 2002;

	self.btnActivate:addClickFuntion(self, self.onActivate);
	self.checkOverview:addClickFuntion(self, self.onCheckOverview);
end

function Lua_HeroGeniusWindow:dispose()
	if self.geniusItems then
		self.geniusItems:dispose();
		self.geniusItems:clear();
		self.geniusItems = nil;
	end
	if self.skillList then
		self.skillList:dispose();
		self.skillList = nil;
	end
	if self.activateEff then
		self.activateEff:dispose();
		self.activateEff = nil;
	end
	self.geniusPos = nil;
	self.heroVo = nil;
	self.data = nil;
	self:superCall("dispose");
end

function Lua_HeroGeniusWindow:showWin(param)
	self:superCall("showWin", param);
	self:updateShowInfo(true);
end

function Lua_HeroGeniusWindow:updateShowInfo()
	self.heroVo = DataCenter.heroData:getItemByUniqueId(self.showData);
	local arr = DataCenter.heroGeniusData:getHeroGeniusList(self.heroVo.id);
	local item;
	for i = 1, arr:getSize() do
		item = self.geniusItems[i];
		if item == nil then
			item = Lua_HeroGeniusItem.new(self.content);
			self.geniusItems:add(item);
		end
		item:setScale(self.geniusPos[i][3], self.geniusPos[i][3], 1);
		item:setLocation(self.geniusPos[i][1], self.geniusPos[i][2], 0);
		item:setClick(self, self.onGeniusClick);
		item:setData(self.heroVo, arr[i]);
	end

	local level = self.selectedIv;
	if level == nil then
		level = self.heroVo.geniusLv;
		level = level <= 0 and 1 or level;
	end
	self.selectedIv = nil;
	self.geniusItems[level]:onClick();
end

function Lua_HeroGeniusWindow:showActivateEff(level)
	local pos = self.geniusPos[level];
	if pos then
		if self.activateEff == nil then
			self.activateEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_hero_jiesuo", "ui_hero_jiesuo", 0, 0);
		end
		self.activateEff:setScale(pos[3], pos[3], 1);
		self.activateEff:setLocation(pos[1], pos[2], 0);
		self.activateEff:setEnable(false);
		self.activateEff:setEnable(true);
	else
		if self.activateEff then
			self.activateEff:setEnable(false);
		end
	end
end

function Lua_HeroGeniusWindow:showSkillMask(bValue)
	if bValue then
		if self.skillMask == nil then
			self.skillMask = UICreate.createUIAtlasImage(self.content, "hero_genius_atlas", "xui_tf_window_7", 0, -114, 644, 670);
		end
		self.skillMask:setEnable(true);
	else
		if self.skillMask then
			self.skillMask:setEnable(false);
		end
	end
end

function Lua_HeroGeniusWindow:onGeniusClick(data)
	local showTween = not (self.data == data);
	self.data = data;
	self.selectedIv = data.talent_lvl;

	for i = 1, self.geniusItems:getSize() do
		if self.geniusItems[i].data == data then
			self.geniusItems[i]:setSelected(true);
		else
			self.geniusItems[i]:setSelected(false);
		end
	end

	self.titleText.text = LanUtil.formateStr(126093, tostring(data.talent_lvl));
	if self.heroVo.geniusLv < data.talent_lvl then
		self:showSkillMask(true);
		self.btnActivate:setEnable(true);
	else
		self:showSkillMask(false);
		self.btnActivate:setEnable(false);
	end

	local skillId = DataCenter.heroGeniusData:getHeroGeniusSkill(self.heroVo.unique_id, data.talent_lvl);
	self.skillList.customParam = skillId;

	self.skillList.showTween = showTween;
	self.skillList:setArrayData(data.skill_list);
	self.skillList.canDrag = not self.skillList.isTheEnd;
end

function Lua_HeroGeniusWindow:onSkillSelected(skillId)
	if self.heroVo == nil or self.data == nil then
		return;
	end

	if skillId == DataCenter.heroGeniusData:getHeroGeniusSkill(self.heroVo.unique_id, self.data.talent_lvl) then
		return;
	end

	if self.heroVo.geniusLv >= self.data.talent_lvl then
		Lua_ProxyManager.getProxy("Lua_HeroProxy"):sGeniusSkillSelect(self.showData, self.data.talent_lvl, skillId);
	else
		OperateAlert.showLangValue(126099);
	end
end

function Lua_HeroGeniusWindow:onActivate(go)
	if self.data == nil then
		return;
	end

	local bUnlock = DataCenter.heroGeniusData:checkGeniusLvIsUnlock(self.data.talent_lvl, self.heroVo.star);
	if not bUnlock then
		local str = DataCenter.heroGeniusData:getGeniusLvUnlockLabel(self.data.talent_lvl);
		OperateAlert.show(LanUtil.formateStr(126091, str));
		return;
	end

	if self.heroVo.geniusLv + 1 < self.data.talent_lvl then
		OperateAlert.showLangValue(126090);
		return;
	end

	Lua_WindowUtil.openWin("Lua_HeroGeniusActivateWindow", Lua_WinParam.ACTION_OPEN, { heroUid = self.showData, geniusId = self.data.id });
end

function Lua_HeroGeniusWindow:onCheckOverview(go)
	Lua_WindowUtil.openWin("Lua_HeroGeniusOverviewWindow", Lua_WinParam.ACTION_OPEN, self.showData);
end










Lua_HeroGeniusItem = class("Lua_HeroGeniusItem", Lua_DisplayObject)
function Lua_HeroGeniusItem:ctor(p)
	self:superCall("ctor", p, "HeroGeniusItem_skin");
end

function Lua_HeroGeniusItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg_2:addClickFuntion(self, self.onClick);
end

function Lua_HeroGeniusItem:dispose()
	if self.lineEff then
		self.lineEff:dispose();
		self.lineEff = nil;
	end
	if self.unlockEff then
		self.unlockEff:dispose();
		self.unlockEff = nil;
	end
	if self.selectEff then
		self.selectEff:dispose();
		self.selectEff = nil;
	end
	self.owner = nil;
	self.callBack = nil;
	self:superCall("dispose")
end

function Lua_HeroGeniusItem:setClick(owner, callBack)
	self.owner = owner;
	self.callBack = callBack;
end

function Lua_HeroGeniusItem:setData(heroVo, geniusId)
	self.data = DataCenter.heroGeniusData:getGeniusConfig(geniusId);

	self.icon:setEnable(true);
	self:showUnlockEff(false);

	local skillId = DataCenter.heroGeniusData:getHeroGeniusSkill(heroVo.unique_id, self.data.talent_lvl);
	if skillId == 0 then
		self.numBg:setEnable(false);
		self.numText:setEnable(false);
	else
		self.numBg:setEnable(true);
		self.numText:setEnable(true);
		self.numText.text = self:getSkillIdx(skillId);
	end

	local bUnlock = DataCenter.heroGeniusData:checkGeniusLvIsUnlock(self.data.talent_lvl, heroVo.star);
	self.bActivite = heroVo.geniusLv >= self.data.talent_lvl;
	if bUnlock then
		-- 已解锁
		if self.bActivite then
			-- 已激活
			if skillId == 0 then
				self.icon:setAltas("hero_genius_atlas", "xui_tf_button_2");
				self.icon:SetDimensions(44, 45);
			else
				local skillCfg = Lua_SkillConfigData.getConfigData(skillId);
				self.icon:setAltas(skillCfg.atlas, skillCfg.sprite);
				self.icon:SetDimensions(92, 92);
			end
		else
			self.icon:setEnable(false);
			self:showUnlockEff(true);
		end
	else
		self.icon:setAltas("hero_genius_atlas", "xui_tf_label_1");
		self.icon:SetDimensions(76, 75);
	end
	self:showLineEff();
end

function Lua_HeroGeniusItem:getSkillIdx(id)
	local list = self.data.skill_list;
	for i = 1, #list do
		if list[i] == id then
			return i;
		end
	end
	return 0;
end

function Lua_HeroGeniusItem:showLineEff()
	if self.data.talent_lvl > 1 then
		if self.lineEff == nil then
			self.lineEff = UICreate.createUIEffect(self.content, nil, nil, 0, 0);
			self.lineEff.siblingIndex = 0;
		end
		self.lineEff:setEnable(true);
		if self.bActivite then
			self.lineEff:setUrl("/effects/uiEffects/ui_hero_jihuo", "ui_hero_jihuo");
		else
			self.lineEff:setUrl("/effects/uiEffects/ui_hero_weijihuo", "ui_hero_weijihuo");
		end
		if self.data.talent_lvl == 2 then
			self.lineEff:setScale(1, 1, 1);
			self.lineEff:setRot(0, 0, 20);
			self.lineEff:setLocation(-108.5, -26.5, 0);
		elseif self.data.talent_lvl == 3 then
			self.lineEff:setScale(0.8, 1, 1);
			self.lineEff:setRot(0, 0, -30);
			self.lineEff:setLocation(-90, 20.5, 0);
		else
			self.lineEff:setScale(1, 1, 1);
			self.lineEff:setRot(0, 0, 25);
			self.lineEff:setLocation(-99.5, -30, 0);			
		end
	else
		if self.lineEff then
			self.lineEff:setEnable(false);
		end
	end
end

function Lua_HeroGeniusItem:showUnlockEff(bValue)
	if bValue then
		if self.unlockEff == nil then
			self.unlockEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_hero_kejihuo", "ui_hero_kejihuo", 0, 0);
		end
		self.unlockEff:setEnable(true);
	else
		if self.unlockEff then
			self.unlockEff:setEnable(false);
		end
	end
end

function Lua_HeroGeniusItem:setSelected(bValue)
	if bValue then
		if self.selectEff == nil then
			self.selectEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_hero_xz", "ui_hero_xz", 0, 0);
		end
		self.selectEff.siblingIndex = self.icon.siblingIndex + 1;
		self.selectEff:setEnable(true);
	else
		if self.selectEff then
			self.selectEff:setEnable(false);
		end
	end
end

function Lua_HeroGeniusItem:onClick(go)
	if self.owner and self.callBack then
		self.callBack(self.owner, self.data);
	end
end










Lua_HeroGeniusSkillItem = class("Lua_HeroGeniusSkillItem", Lua_ListCell)
function Lua_HeroGeniusSkillItem:ctor(p)
	self:superCall("ctor", p, "HeroGeniusSkillItem_skin");
end

function Lua_HeroGeniusSkillItem:buildShowItem()
	self:superCall("buildShowItem");
	self.skillIcon:addClickFuntion(self, self.onCheckDetails);
	self.checkDetails:addClickFuntion(self, self.onCheckDetails);
end

function Lua_HeroGeniusSkillItem:dispose()
	self.selectSkill = nil;
	self:superCall("dispose");
end

function Lua_HeroGeniusSkillItem:setCellSeqIndex(idx)
	self:superCall("setCellSeqIndex", idx);
	self.numText.text = idx;
end

function Lua_HeroGeniusSkillItem:setCustomParam(customParam)
	self.selectSkill = customParam;
end

function Lua_HeroGeniusSkillItem:setData(skillId)
	self.skillId = skillId;
	local config = Lua_SkillConfigData.getConfigData(skillId);
	self.skillIcon:setAltas(config.atlas, config.sprite);
	self.nameText.text = config.name;
	self.nameText:resetSize();

	self.desText.verticalOverflowValue = 1;
	self.desText.text = config.des;
	self.desText:resetSize();
	if self.desText.height > 87 then
		self.desText:SetDimensions(400, 87);
		self.desText.verticalOverflowValue = 0;
		self.checkDetails:setEnable(true);
	else
		self.checkDetails:setEnable(false);
	end

	self.stateText:setLocation(self.nameText.posX + self.nameText.width + 13.5, 51, 0);
	self.stateText:setEnable(skillId == self.selectSkill);
	self.selectSign:setEnable(skillId == self.selectSkill);
end

function Lua_HeroGeniusSkillItem:onPressClick()
	Lua_MsgUtil.callFunc("HERO_GENIUS_SKILL_SELECT", self.skillId);
end

function Lua_HeroGeniusSkillItem:onCheckDetails(go)
	Lua_WindowUtil.openWin("Lua_SkillTipsWindow", Lua_WinParam.ACTION_OPEN, self.skillId);
end