Lua_HeroMaterialSelectWindow = class("Lua_HeroMaterialSelectWindow", Lua_Window);
function Lua_HeroMaterialSelectWindow:ctor()
	self:superCall("ctor");
	
	self.windowName = "Lua_HeroMaterialSelectWindow"
	self.skinName = "HeroMaterialSelectWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_HeroMaterialSelectWindow:buildShowItem()
	self:superCall("buildShowItem")
	DataCenter.heroMaterialData:updateLineupState()
	self.selectedList = Array()

	self:addLuaEvent("HERI_MATERIAL_SELECT", self, self.onMaterialSelected)

	self.itemList = Lua_DragList.new(self.content, 644, 505, Lua_AxisDefine.Vertical)
	self.itemList:setLocation(0, 90)
	self.itemList:setListCell(Lua_HeroMaterialSelectItem, 158, 229, 4)
	self.itemList:setCellSpacing(4, 8)
	self.itemList.customParam = self.selectedList

	self.btnSure:addClickFuntion(self, self.onBtnSureClick)
end

function Lua_HeroMaterialSelectWindow:dispose()
	if self.itemList then
		self.itemList:dispose()
		self.itemList = nil
	end
	if self.selectedList then
		self.selectedList:clear()
		self.selectedList = nil
	end
	self:superCall("dispose")
end

function Lua_HeroMaterialSelectWindow:showWin(param)
	self:superCall("showWin", param)

	local arr = param.selectedList
	if arr then
		for i = 1, arr:getSize() do
			self.selectedList:add(arr[i])
		end
	end

	arr = DataCenter.heroMaterialData:getHeroList(param)
	arr:add({ heroId = param.id })
	self.itemList:setArrayData(arr)

	self:updateShowInfo()
end

function Lua_HeroMaterialSelectWindow:updateShowInfo(selectedNum)
	if selectedNum == nil then
		selectedNum = self.selectedList:getSize()
	end
	self.selectedText.text = LanUtil.formateStr(126215, tostring(selectedNum), tostring(self.showData.num))
end

function Lua_HeroMaterialSelectWindow:onMaterialSelected(data)
	if self.selectedList:indexOf(data) == -1 then
		local selectedNum = self.selectedList:getSize()
		if selectedNum == self.showData.num then
			OperateAlert.showLangValue(126208)
		else
			self.selectedList:add(data)
		end
		self:updateShowInfo(selectedNum + 1)
	else
		self.selectedList:removeItem(data)
		self:updateShowInfo()
	end
	self.itemList:updateShowList()
end

function Lua_HeroMaterialSelectWindow:onBtnSureClick(go)
	local len = self.selectedList:getSize()
	local uniqueId
	while len > 0 do
		uniqueId = self.selectedList:remove()
		self.showData:addHeroMaterial(uniqueId)
		len = len - 1
	end
	Lua_MsgUtil.callFunc("UPDATE_HERI_MATERIAL_SELECT", self.showData.index)
	self:hide()
end




















Lua_HeroMaterialSelectItem = class("Lua_HeroMaterialSelectItem", Lua_ListCell)
function Lua_HeroMaterialSelectItem:ctor(p)
    self:superCall("ctor", p)
end

function Lua_HeroMaterialSelectItem:buildShowItem()
	self:superCall("buildShowItem")

    self.heroItemIcon = Lua_HeroItemIcon.new(self.content)
    self.heroItemIcon:setScale(0.92, 0.92)
end

function Lua_HeroMaterialSelectItem:dispose()
	if self.heroItemIcon then
		self.heroItemIcon:dispose()
		self.heroItemIcon = nil
	end
	self.selectedList = nil;
	self.data = nil
	self.heroVo = nil
	self:superCall("dispose")
end

function Lua_HeroMaterialSelectItem:setCustomParam(customParam)
	self.selectedList = customParam;
end

function Lua_HeroMaterialSelectItem:setData(data)
	self.data = data
	self:updateData()
end

function Lua_HeroMaterialSelectItem:updateData()
	if type(self.data) == "number" then
		self.bSelected = self.selectedList:indexOf(self.data) ~= -1
		self.isDownLineup = DataCenter.heroMaterialData:checkIsDownLineup(self.data)

		self.heroVo = DataCenter.heroData:getItemByUniqueId(self.data)
		self.heroItemIcon:setData(self.heroVo)

		if self.bSelected then
			self.heroItemIcon:setLock(false)
			self.heroItemIcon:setMask(true)
			self.heroItemIcon:setTick(true)
		elseif self.heroVo.lock_state or (self.heroVo.isUpLineup and not self.isDownLineup) then
			self.heroItemIcon:setLock(true)
			self.heroItemIcon:setMask(true)
			self.heroItemIcon:setTick(false)
		else
			self.heroItemIcon:setLock(false)
			self.heroItemIcon:setMask(false)
			self.heroItemIcon:setTick(false)
		end
		self.heroItemIcon:setAddIcon(false)
	else
		self.bSelected = false
		self.isDownLineup = false
		self.heroVo = nil
		self.heroItemIcon:setData(nil)
		self.heroItemIcon:setLock(false)
		self.heroItemIcon:setMask(false)
		self.heroItemIcon:setTick(false)
		self.heroItemIcon:setAddIcon(true)
	end
end

function Lua_HeroMaterialSelectItem:onPressClick()
	if self.heroVo == nil then
		local data = Lua_HeroConfigData.getConfig(self.data.heroId)
		DataCenter.packUtil:openPathWindow(data.itemId, false)
		return
	end

	if self.bSelected then --已选中，点击解锁
		self:onSureFun();
		return
	end

    if self.heroVo.isUpLineup and not self.isDownLineup then --是否显示下阵tips
        self:showHeroLineupTips();
        return;
    end

    if self.heroVo.lock_state then--上锁tips
        self:showHeroUnlockTips();
        return;
    end

    if self.heroVo.bcore then --核心tips
        self:showBcoreTips();
        return
    end

    self:onSureFun()
end

--英雄下阵
function Lua_HeroMaterialSelectItem:showHeroLineupTips()
    local tipData = { des = LanUtil.formateStr(126221, self.heroVo.upLineupName), btnType = 1, owner = self, sureFun = self.onHeroLineup };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

--英雄下阵
function Lua_HeroMaterialSelectItem:onHeroLineup()
    local bDownLineup, showName = DataCenter.heroMaterialData:checkLineupStateAndNum(self.selectedList, self.data);
    if bDownLineup then--是否可以下阵
        OperateAlert.showLangValue(126222);
        DataCenter.heroMaterialData:setDownLineup(self.data);
    else
        OperateAlert.show(LanUtil.formateStr(126223, showName));
        return
    end
    
    if self.heroVo.lock_state then--上锁tips
        self:showHeroUnlockTips();
        return;
    end

    if self.heroVo.bcore then --核心tips
        self:showBcoreTips();
        return
    end

    self:onSureFun();
end

--英雄解锁tips
function Lua_HeroMaterialSelectItem:showHeroUnlockTips()
    local tipData = { des = LanUtil.getValue(126219), btnType = 1, owner = self, sureFun = self.onUnlock };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

--英雄解锁
function Lua_HeroMaterialSelectItem:onUnlock()
    Lua_ProxyManager.getProxy("Lua_HeroProxy"):sHeroLock(self.heroVo.unique_id, 0);

    if self.heroVo.bcore then --核心tips
	    OperateAlert.showLangValue(126224);--提示已解锁
        self:showBcoreTips();
        return
    end

    OperateAlert.showLangValue(126220);--提示已解锁，并勾选
    self:onSureFun();
end

--消耗核心英雄Tips
function Lua_HeroMaterialSelectItem:showBcoreTips()
    local tipData = { des = LanUtil.getValue(126207), btnType = 1, owner = self, sureFun = self.onSureFun };
    Lua_WindowUtil.openWin("Lua_TipsWindow", Lua_WinParam.ACTION_OPEN, tipData);
end

function Lua_HeroMaterialSelectItem:onSureFun()
    Lua_MsgUtil.callFunc("HERI_MATERIAL_SELECT", self.heroVo.unique_id)
end