checkRequire("Lua_HeroTrialTipItem");
Lua_HeroTotemPanel = class("Lua_HeroTotemPanel", Lua_DisplayObject)
function Lua_HeroTotemPanel:ctor(p)
	self:superCall("ctor", p, "HeroTotemPanel_skin");
end

function Lua_HeroTotemPanel:buildShowItem()
	self:superCall("buildShowItem");
	
	self.partLen = 6;
	self.partItems = Array(); -- 部位对象
	local posDic = {{-278, 519}, {-167.5, 475.5}, {-56, 464}, {56, 464}, {167.5, 475.5}, {278, 519}};
	local item;
	for i = 1, self.partLen do
		item = Lua_HeroTotemItem.new(self.content);
		item.content.name = "Lua_HeroTotemItem" .. i;
		item:setRectAnchor(7);
		item:setLocation(posDic[i][1], posDic[i][2], 0);
		item:setClick(self, self.onPartClick);
		self.partItems:add(item);
	end

	self.attrItems = Array(); -- 属性对象
	self.attrArr = Array(); -- 属性数据

	self.suitContainer = Lua_DragContainer.new(self.content, 600, 76, Lua_AxisDefine.Vertical);
	self.suitContainer:setRectAnchor(7);
	self.suitContainer:setLocation(0, 285, 0);

	self.btnSynthesis:addClickFuntion(self, self.onSynthesis);
	self.btnHandbook:addClickFuntion(self, self.onCheckHandbook);
	self.checkAttr:addClickFuntion(self, self.onCheckAttr);
	self.btnRemove:addClickFuntion(self, self.onRemoveClick);
	self.btnWear:addClickFuntion(self, self.onWearClick);
end

function Lua_HeroTotemPanel:dispose()
	if self.partItems then
		self.partItems:dispose();
		self.partItems:clear();
		self.partItems = nil;
	end

	if self.attrItems then
		self.attrItems:dispose();
		self.attrItems:clear();
		self.attrItems = nil;
	end
	if self.attrArr then
		self.attrArr:clear();
		self.attrArr = nil;
	end

	if self.suitContainer then
		self.suitContainer:dispose();
		self.suitContainer = nil;
	end

	self.data = nil;
	DataCenter.winTweenManager:removeWinTween(self.tweenName);
	self:superCall("dispose")
end

function Lua_HeroTotemPanel:updateHeroPanelInfo(data, isSHowAtlas)
	self.data = data;
	self.attrArr:clear();
	
	local unlockLv;
	for i = 1, self.partLen do
		unlockLv = DataCenter.totemUtil:getPartUnlockLv(i);
		self.partItems[i]:setPart(i, data.level >= unlockLv);
		self.partItems[i]:setData(nil, data.trial_state);
	end

	local info = DataCenter.totemData:getHeroTotemInfo(data.unique_id);
	local list = info ~= nil and info.totem_item or nil;
	local len = list ~= nil and #list or 0;
	local vo;
	local attrDic = {};
	for i = 1, len do
		vo = DataCenter.totemData:getTotemItemVo(list[i].unique_id);
		self.partItems[vo.part]:setData(vo, data.trial_state);

		attrDic = self:calcAttr(vo.totem_info.prop, attrDic);
		attrDic = self:calcAttr(vo.totem_info.entry_prop, attrDic);
		attrDic = self:calcAttr(vo.totem_info.entry_prop_ex, attrDic);
	end

	list = DataCenter.totemUtil.showAttrList;
	len = #list;
	for i = 1, #list do
		item = self.attrItems[i];
		if item == nil then
			item = Lua_AttrIconItem.new(self.content);
			item.pivot = 1;
			item:setRectAnchor(7);
			item:setTextStyle(Lua_MyUISettings.defaultFontName, 22, "FFFFFF", 2, "000000");
			self.attrItems:add(item);
		end
		vo = DataCenter.attributesUtil:createAttrVo(list[i]);
		if attrDic[vo.id] == nil then
			item:setData("common_altas_2", vo.hero_attr_icon, 0);
		else
			item:setData("common_altas_2", vo.hero_attr_icon, attrDic[vo.id].showValue);
		end
	end
	local space = 125;
	local w = -(space * len) / 2 + space / 2;
	for i = 1, len do
		item = self.attrItems[i];
		item:setLocation(((i - 1) % len) * space + w - 10, 355, 0);
	end

	local suitStr1;
	local suitStr2;
	table.clear(attrDic);
	list = info ~= nil and info.suit_list or nil;
	len = list ~= nil and #list or 0;
	local config;
	local skillList;
	for i = 1, len do
		config = DataCenter.totemUtil:getSuitConfig(list[i]);
		attrDic = DataCenter.attributesUtil:getAttrDic(config.prop, attrDic);
		skillList = config.effect_skill_list;
		if skillList then
			for j = 1, #skillList do
				config = Lua_SkillConfigData.getConfigData(skillList[j]);
				if strIsNullOrEmpty(suitStr2) then
					suitStr2 = config.des;
				else
					suitStr2 = suitStr2.."\n"..config.des;
				end
			end
		end
	end
	suitStr1 = DataCenter.attributesUtil:getAttrStr(attrDic);
	if strIsNullOrEmpty(suitStr1) then
		suitStr1 = LanUtil.getValue(20);
	end
	if strIsNullOrEmpty(suitStr2) then
		suitStr2 = LanUtil.getValue(20);
	end
	self.suitContainer:clearList();
	self.suitContainer:addSubContainer(Lua_HeroTotemSuitAttrItem, { key = 1, value = suitStr1 });
	self.suitContainer:addSubContainer(Lua_HeroTotemSuitAttrItem, { key = 2, value = suitStr2 });
	self.suitContainer:updateChildPos();
	self.suitContainer.canDrag = not self.suitContainer.isTheEnd;

	if self.tweenName == nil then
		self.tweenName = DataCenter.winTweenManager:createWinTween(self.content.name, self.content.transform);
	end

	self.btnRemove:setEnable(not data.trial_state);
    self.btnWear:setEnable(not data.trial_state);
    self:showTrialTipItem(data.trial_state);
end

function Lua_HeroTotemPanel:calcAttr(list, attrDic)
	if list then
		local name;
		local vo;
		for i = 1, #list do
			name = list[i].name;
			if attrDic[name] == nil then
				vo = DataCenter.attributesUtil:createAttrVo(name);
				if vo then
					vo.value = list[i].value;
					attrDic[name] = vo;
					self.attrArr:add(vo);
				end
			else
				attrDic[name].value = attrDic[name].value + list[i].value;
			end
		end
	end
	return attrDic;
end

function Lua_HeroTotemPanel:onPartClick(part, data)
	if data == nil then
		if self.data.trial_state then
			OperateAlert.showLangValue(126797);
			return;
		end
		Lua_WindowUtil.openWin("Lua_TotemReplaceWindow", Lua_WinParam.ACTION_OPEN, { part = part, heroUid = self.data.unique_id });
	else
		DataCenter.packUtil:showItemInfo(data, not self.data.trial_state, self.data.unique_id);
	end
end

function Lua_HeroTotemPanel:onSynthesis(go)
	Lua_WindowUtil.openWin("Lua_TotemSynthesisWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_HeroTotemPanel:onCheckHandbook(go)
	Lua_WindowUtil.openWin("Lua_TotemHandbookWindow", Lua_WinParam.ACTION_OPEN);
end

function Lua_HeroTotemPanel:onCheckAttr(go)
	if self.attrArr == nil or self.attrArr:getSize() <= 0 then
		OperateAlert.showLangValue(762041);
		return;
	end
	self.attrArr:sort("sort", false);
	Lua_WindowUtil.openWin("Lua_TotemAttributeWindow", Lua_WinParam.ACTION_OPEN, self.attrArr);
end

function Lua_HeroTotemPanel:onRemoveClick(go)
	local info = DataCenter.totemData:getHeroTotemInfo(self.data.unique_id);
	if info == nil and info.totem_item == nil or #info.totem_item <= 0 then
		OperateAlert.showLangValue(762036);
		return;
	end

	local arr = Array();
	for i = 1, #info.totem_item do
		arr:add(info.totem_item[i].unique_id);
	end
	Lua_ProxyManager.getProxy("Lua_TotemProxy"):sRemove(self.data.unique_id, arr);
end

function Lua_HeroTotemPanel:onWearClick(go)
	local info = DataCenter.totemData:getHeroTotemInfo(self.data.unique_id);
	local list = info ~= nil and info.totem_item or nil;
	local totemLen = list ~= nil and #list or 0;

	local arr = DataCenter.packData:getItemArrByPackType(Lua_PackDefine.TYPE_TOTEM);
	local dataLen = arr ~= nil and arr:getSize() or 0;
	if dataLen <= 0 then
		OperateAlert.showLangValue(762040);
		return;
	end

	local wearDic = {};
	self.wearDic = {}; -- 穿戴的图腾
	self.suitDic = {}; -- 激活的套装
	self.partDic = {}; -- 部位
	local vo;
	for i = 1, totemLen do
		vo = DataCenter.totemData:getTotemItemVo(list[i].unique_id);
		wearDic[vo.unique_id] = 1;
		self.wearDic[vo.unique_id] = 1;
		self.partDic[vo.part] = vo;
	end

	list = info ~= nil and info.suit_list or nil;
	local len = list ~= nil and #list or 0;
	for i = 1, len do
		self.suitDic[list[i]] = 1;
	end

	if totemLen < self.partLen then
		-- 根据已有的穿戴同类型
		local subTypeDic = {};
		for i = 1, totemLen do
			vo = DataCenter.totemData:getTotemItemVo(info.totem_item[i].unique_id);
			if subTypeDic[vo.sub_type] == nil then
				subTypeDic[vo.sub_type] = 1;
				self:onWearByType(vo.sub_type);
			end
		end
		-- self:checkSuitState();
	
		-- 根据推荐补齐
		self:onWearBySuit();

		-- 根据部位补齐
		self:onWearByPart();
	end

	-- 根据条件穿戴最好的
	self:onWearByReplace();

	arr = Array();
	for _, v in pairs(self.partDic) do
		if wearDic[v.unique_id] == nil then
			arr:add(v.unique_id);
		end
	end
	if arr:getSize() <= 0 then
		OperateAlert.showLangValue(762040);
		return;
	end
	Lua_ProxyManager.getProxy("Lua_TotemProxy"):sWear(self.data.unique_id, arr, 0);
end

function Lua_HeroTotemPanel:onWearBySuit()
	local recoSuits = self.data.recoTotemSuit;
	if recoSuits then
		local suitId;
		for i = 1, #recoSuits do
			suitId = recoSuits[i];
			if self.suitDic[suitId] == nil then
				self:onWearBySuitId(suitId);
			end
		end
	end
end

function Lua_HeroTotemPanel:onWearBySuitId(suitId)
	local config = DataCenter.totemUtil:getSuitConfig(suitId);
	local arr = DataCenter.packData:getUnIdListByTypeOnSort(Lua_PackDefine.TYPE_TOTEM, Lua_PackDefine.TOTEM, config.totem_type);
	local dataLen = arr ~= nil and arr:getSize() or 0;
	if dataLen <= 0 then
		return;
	end

	-- 套装激活所需数量 n件同类型不同部位
	local partTab = {};
	local partLen = 0;
	local vo;
	for i = 1, dataLen do
		vo = DataCenter.packData:getItemVoByUnId(arr[i]);
		if partTab[vo.part] == nil then
			partTab[vo.part] = 1;
			partLen = partLen + 1;
		end
	end
	if partLen >= config.need_amount then
		for part in pairs(partTab) do
			if self.partDic[part] == nil then
				for i = 1, dataLen do
					vo = DataCenter.packData:getItemVoByUnId(arr[i]);
					if self.wearDic[vo.unique_id] == nil and vo.part == part then
						self.wearDic[vo.unique_id] = 1;
						self.partDic[part] = vo;
						break;
					end
				end
			end
		end
		self.suitDic[suitId] = 1;
	end
end

function Lua_HeroTotemPanel:onWearByType(totemType)
	local arr = DataCenter.packData:getUnIdListByTypeOnSort(Lua_PackDefine.TYPE_TOTEM, Lua_PackDefine.TOTEM, totemType);
	local dataLen = arr ~= nil and arr:getSize() or 0;
	if dataLen <= 0 then
		return;
	end

	local vo;
	for part = 1, self.partLen do
		if self.partDic[part] == nil then
			for i = 1, dataLen do
				vo = DataCenter.packData:getItemVoByUnId(arr[i]);
				if self.wearDic[vo.unique_id] == nil and vo.part == part then
					self.wearDic[vo.unique_id] = 1;
					self.partDic[part] = vo;
					break;
				end
			end
		end
	end
end

function Lua_HeroTotemPanel:onWearByPart()
	local vo;
	for part = 1, self.partLen do
		if self.partDic[part] == nil then
			local arr = DataCenter.packData:getUnIdListByPartOnSort(Lua_PackDefine.TYPE_TOTEM, Lua_PackDefine.TOTEM, part);
			for i = 1, arr:getSize() do
				vo = DataCenter.packData:getItemVoByUnId(arr[i]);
				if self.wearDic[vo.unique_id] == nil then
					self.wearDic[vo.unique_id] = 1;
					self.partDic[part] = vo;
					break;
				end
			end
		end
	end
end

-- function Lua_HeroTotemPanel:checkSuitState()
-- 	local vo;
-- 	local suitCfg;
-- 	for part = 1, self.partLen do
-- 		vo = self.partDic[part];
-- 		if vo and vo.suitId > 0 then
-- 			suitCfg = DataCenter.totemUtil:getSuitConfig(vo.suitId);
-- 			if not self:checkSuitIsExist(suitCfg) and self:checkSuitActivate(suitCfg) then
-- 				self.suitDic[vo.suitId] = 1;
-- 			end
-- 		end
-- 	end
-- end

-- function Lua_HeroTotemPanel:checkSuitIsExist(suitCfg)
-- 	if self.suitDic[suitCfg.id] == 1 then
-- 		return true;
-- 	end

-- 	local config;
-- 	for k in pairs(self.suitDic) do
-- 		config = DataCenter.totemUtil:getSuitConfig(k);
-- 		if config.totem_type == suitCfg.totem_type then
-- 			return true;
-- 		end
-- 	end
-- 	return false;
-- end

-- function Lua_HeroTotemPanel:checkSuitActivate(suitCfg)
-- 	local temp;
-- 	local num = 0;
-- 	for part = 1, self.partLen do
-- 		temp = self.partDic[part];
-- 		if temp and temp.sub_type == suitCfg.totem_type and temp.star >= suitCfg.need_star then
-- 			num = num + 1;
-- 		end
-- 	end
-- 	return num >= suitCfg.need_amount;
-- end

function Lua_HeroTotemPanel:onWearByReplace()
	local wearVo;
	local vo;
	for part = 1, self.partLen do
		wearVo = self.partDic[part];
		if wearVo then
			local arr = DataCenter.totemData:getTotemArrByPart(part, wearVo.unique_id, true);
			for i = 1, arr:getSize() do
				vo = DataCenter.packData:getItemVoByUnId(arr[i]);
				if vo.sub_type == wearVo.sub_type then
					if vo.star > wearVo.star then
						self.partDic[part] = vo;
						break;
					elseif vo.star == wearVo.star then
						if vo.strengthenLv > wearVo.strengthenLv then
							self.partDic[part] = vo;
							break;
						elseif vo.strengthenLv == wearVo.strengthenLv then
							if vo.score > wearVo.score then
								self.partDic[part] = vo;
								break;
							end
						end
					end
				end
			end
		end
	end
end

-- 显示试用英雄提示Item
function Lua_HeroTotemPanel:showTrialTipItem(val)
    if val then 
        if self.trialTipItem == nil then
            self.trialTipItem = Lua_HeroTrialTipItem.new(self.content,2);
            self.trialTipItem:setRectAnchor(7);
            self.trialTipItem:setLocation(0, 187, 0);
        end
        self.trialTipItem:setData(self.data);
        self.trialTipItem:setEnable(true);
    else
        if self.trialTipItem ~= nil then
            self.trialTipItem:setData(nil);
            self.trialTipItem:setEnable(false);
        end
   end
end












Lua_HeroTotemItem = class("Lua_HeroTotemItem", Lua_DisplayObject)
function Lua_HeroTotemItem:ctor(p)
	self:superCall("ctor", p, "HeroTotemItem_skin");
end

function Lua_HeroTotemItem:buildShowItem()
	self:superCall("buildShowItem");
	self.bg:addClickFuntion(self, self.onClick);
end

function Lua_HeroTotemItem:dispose()
	if self.starList then
		self.starList:dispose();
		self.starList:clear();
		self.starList = nil;
	end
	if self.redPoint then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	self.owner = nil;
	self.callBack = nil;
	self.data = nil;
	self:superCall("dispose")
end

function Lua_HeroTotemItem:setClick(owner, callBack)
	self.owner = owner;
	self.callBack = callBack;
end

function Lua_HeroTotemItem:setPart(part, bUnlock)
	self.part = part;
	self.bUnlock = bUnlock;
end

function Lua_HeroTotemItem:setData(data, trialState)
	self.data = data;
	self.trialState = trialState;

	self.bg:setAltas("totem_atlas", "xui_hbtt_window_"..(self.part + 5));
	self.bg:SetDimensions(116, 88);
	self.levelBg:setEnable(false);
	self.levelText:setEnable(false);
	local state = false;
	if not self.bUnlock then
		self.stateIcon:setEnable(true);
		self.stateIcon:setAltas("totem_atlas", "xui_hbtt_button_21");
		self:showStar(0);
	elseif data == nil then
		self.stateIcon:setEnable(true);
		self.stateIcon:setAltas("totem_atlas", "xui_hbtt_button_22");
		self:showStar(0);
		state = DataCenter.totemData:checkWearReplaceRed(self.part);
	else
		self.stateIcon:setEnable(false);
		self.bg:setAltas(data.atlas, data.sprite);
		self.bg:SetDimensions(112, 112);
		local level = data.strengthenLv;
		if level > 0 then
			self.levelBg:setEnable(true);
			self.levelText:setEnable(true);
			self.levelText.text = LanUtil.formateStr(10049, tostring(level));
		end
		
		self:showStar(data.star);
		state = DataCenter.totemData:checkWearReplaceRed(self.part, data);
	end
	self:showRedPoint(state and not trialState);
end

function Lua_HeroTotemItem:showStar(num)
	if num > 0 and self.starList == nil then
		self.starList = Array();
	end
	local len = self.starList ~= nil and self.starList:getSize() or 0;
	local maxLen = num > len and num or len;
	local icon;
	for i = 1, maxLen do
		icon = self.starList[i];
		if i > num then
			if icon then
				icon:setEnable(false);
			end
		else
			if icon == nil then
				icon = UICreate.createUIAtlasImage(self.content, "common_altas_1", "xui_common_label_09", 0, 0, 0, 0);
				self.starList:add(icon);
			else
				icon:setEnable(true);
			end
		end
	end
	if num > 0 then
		local space = 12
		local w = -(space * num) / 2 + space / 2
		for i = 1, num do
			icon = self.starList[i]
			icon:setLocation(((i - 1) % num) * space + w, -40, 0)
		end
	end
end

function Lua_HeroTotemItem:showRedPoint(bValue)
	if bValue then
		if self.redPoint == nil then
			self.redPoint = Lua_RedPointIcon.new(self.content);
			self.redPoint:setLocation(30, 25, 0);
			self.redPoint:createRedPointEff();
		end
		self.redPoint:updateRedPointShow(true);
	else
		if self.redPoint then
			self.redPoint:updateRedPointShow(false);
		end
	end
end

function Lua_HeroTotemItem:onClick(go)
	if not self.bUnlock then
		if self.trialState then
			OperateAlert.showLangValue(126797);
			return;
		end
		local unlockLv = DataCenter.totemUtil:getPartUnlockLv(self.part);
		OperateAlert.show(LanUtil.formateStr(762032, tostring(unlockLv)));
		return;
	end

	if self.owner and self.callBack then
		self.callBack(self.owner, self.part, self.data);
	end
end










Lua_HeroTotemSuitAttrItem = class("Lua_HeroTotemSuitAttrItem", Lua_DragContainerItem)
function Lua_HeroTotemSuitAttrItem:ctor(p)
	self:superCall("ctor", p);
end

function Lua_HeroTotemSuitAttrItem:buildShowItem()
	self:superCall("buildShowItem");

	self.titleText = UICreate.createLabel(self.content, nil, -295, 0, 100, 31, 24);
	self.titleText.anchorValue = 1;
	self.titleText.pivotValue = 0;
	self.titleText.alignmentValue = 0;
	self.titleText.horizontalOverflowValue = 1;
	self.titleText.verticalOverflowValue = 1;
	self.titleText:setEffectDistance(2, 2);
	self.titleText.effectColorStr = Lua_ColorDefine.transColorStr("070809");

	self.desText = UICreate.createLabel(self.content, nil, -160, 0, 460, 31, 24);
	self.desText.anchorValue = 1;
	self.desText.pivotValue = 0;
	self.desText.alignmentValue = 0;
	self.desText.horizontalOverflowValue = 0;
	self.desText.verticalOverflowValue = 1;
	self.desText:setEffectDistance(2, 2);
	self.desText.effectColorStr = Lua_ColorDefine.transColorStr("070809");
end

function Lua_HeroTotemSuitAttrItem:dispose()
	self:superCall("dispose");
end

function Lua_HeroTotemSuitAttrItem:setData(data)
	if data.key == 1 then
		self.titleText.colorStr = Lua_ColorDefine.transColorStr("64BE7E");
		self.desText.colorStr = Lua_ColorDefine.transColorStr("64BE7E");
		self.titleText:setLangValue(762005);
	else
		self.titleText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self.desText.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self.titleText:setLangValue(762006);
	end
	self.desText.text = data.value;
	self.desText:resetSize();
end

function Lua_HeroTotemSuitAttrItem:getWidth()
	return 600;
end

function Lua_HeroTotemSuitAttrItem:getHeight()
	return self.desText.height + 7;
end