Lua_HeroWeaponSkillWindow = class("Lua_HeroWeaponSkillWindow", Lua_Window)
function Lua_HeroWeaponSkillWindow:ctor()
	self:superCall("ctor")

	self.w = 430
	self.windowName = "Lua_HeroWeaponSkillWindow"
	self.skinName = "HeroWeaponSkillWindow_skin"
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_HeroWeaponSkillWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.scoreNum = Lua_NumberImage.new(self.showObject)
	self.scoreNum:setLocation(45.5, -118, 0)
	self.scoreNum.pivot = 1
	self.scoreNum.numOffsetX = -8
	self.scoreNum.numAtlas = "number"
	self.scoreNum.preStr = "xui_zssb_number_"
end

function Lua_HeroWeaponSkillWindow:dispose()
	if self.scoreNum then
		self.scoreNum:dispose()
		self.scoreNum = nil
	end
	if self.textArea then
		self.textArea:dispose()
		self.textArea = nil
	end
	if self.attrArr then
		self.attrArr:dispose()
		self.attrArr:clear()
		self.attrArr = nil
	end
	self:superCall("dispose")
end

function Lua_HeroWeaponSkillWindow:showWin(param)
	self:superCall("showWin", param)
	self:updateShowInfo(param.data)
end

function Lua_HeroWeaponSkillWindow:updateShowInfo(param)
	local spacingH = 21 -- 间距
	local baseH = 335
	local addH = spacingH * 3
	local maxH = 1073 - baseH - addH -- 剩下神兵描述、技能描述

	self.heroName.text = LanUtil.formateStr(390005, param.name)

	local data
	if param.weapon_id > 0 then -- 已解锁
		data = DataCenter.heroUtil:getHeroWeaponVo(param.weapon_id)
	else
		data = DataCenter.heroUtil:getHeroWeaponVo(param.weaponId)
	end
	self.weaponImg:setUrl(data.uiPicUrl)
	self.nameText.text = data.name
	self.desText.text = data.des
	self.desText:resetSize()
	addH = addH + self.desText.height

	local level = 0
	local config
	local skillCfg
	local str
	local skillStr = ""
	local buffArr = Array()
	while true do
		config = DataCenter.heroUtil:getHeroWeaponVo(param.weaponId + level)
		if config.show_tips == 1 then
			skillCfg = Lua_SkillConfigData.getConfigData(config.skill[1])
			if config.level == 0 then
				str = spliceStr(LanUtil.getValue(390006), skillCfg.des)
			else
				str = spliceStr(LanUtil.formateStr(390007, tostring(config.level)), skillCfg.des)
			end
			if not self.showData.isSHowAtlas and not (param.weapon_id > 0 and config.level <= data.level) then -- 未激活
				str = string.gsub(str, "499E6A", "85868B")
				str = Lua_ColorDefine.getColorStr("85868B", str)
			end

			if config.next_id == nil or config.next_id <= 0 then
				skillStr = spliceStr(skillStr, str)
			else
				skillStr = spliceStr(skillStr, str, "\n\n")
			end

			if skillCfg.buff_list then
				for i = 1, #skillCfg.buff_list do
					buffArr:add(skillCfg.buff_list[i])
				end
			end
		end
		if config.next_id == nil or config.next_id <= 0 then
			break
		end
		level = level + 1
	end

	local buffLen = buffArr:getSize()
	local buffH = self:showBuff(buffArr)
	if buffLen > 0 then
		buffH = buffH + buffLen * spacingH
	end
	addH = addH + buffH

	local height = self:showSkillText(skillStr, maxH - buffH - self.desText.height)
	addH = addH + height

	local starY
	if buffH > 0 then
		starY = self.skillText.posY - height - spacingH
		self.line_1:setLocation(0, starY, 0)
		local showH = 0;
		for i = 1, buffLen do
			self.buffArr[i]:setLocation(0, starY - spacingH - showH, 0)
			showH = showH + self.buffArr[i].showHeight
		end
	end

	starY = self.skillText.posY - buffH - height - spacingH
	self.line_2:setLocation(0, starY, 0)
	self.desText:setLocation(-185, self.line_2.posY - spacingH, 0)

	self.winBg:SetDimensions(self.w, baseH + addH)
	local posY = self.winBg.height / 2 + 24
	LuaUtil.setObjPos(self.showObject, 0, posY, 0)
	self.closeText:setLocation(0, -posY - 11.5, 0)

	local attrArr
	if param.weapon_id > 0 then
		self.scoreNum.num = data.score
		self.levelText.text = LanUtil.formateStr(390004, tostring(data.level))
		attrArr = DataCenter.attributesUtil:getAttrArrByDic(data.prop)
	else
		self.scoreNum.num = config.score
		self.levelText.text = LanUtil.formateStr(390004, tostring(level)) -- 显示最高级信息
		attrArr = DataCenter.attributesUtil:getAttrArrByDic(config.prop)
	end
	self:showAttributes(attrArr)
end

function Lua_HeroWeaponSkillWindow:showSkillText(str, maxH)
	self.skillText:setEnable(true)
	self.skillText.text = str
	self.skillText:resetSize()
	local height = self.skillText.height
	if height > maxH then
		height = maxH
		self.skillText:setEnable(false)
		if self.textArea == nil then
			self.textArea = Lua_TextArea.new(self.showObject, 375, height)
			self.textArea:setRectPivot(1)
			self.textArea:setLocation(0, self.skillText.posY, 0)
		end
		self.textArea:setText(str, 22, 0.9)
	end
	return height
end

function Lua_HeroWeaponSkillWindow:showAttributes(arr)
	if self.attrArr == nil then
		self.attrArr = Array()
	end
	local len = self.attrArr:getSize()
	local dataLen = arr:getSize()
	local maxLen = dataLen > len and dataLen or len
	local item
	local posX
	local posY
	for i = 1, maxLen do
		item = self.attrArr[i]
		if i > dataLen then
			if item then
				item:setEnable(false)
			end
		else
			if item == nil then
				item = Lua_AttrIconItem.new(self.showObject)
				self.attrArr:add(item)
			else
				item:setEnable(true)
			end
			item.pivot = 1
			item.spacingX = 11
			posX = -172 + ((i - 1) % 2) * 202.5
			posY = -213 + Mathf.Floor((i - 1) / 2) * -37
			item:setLocation(posX, posY, 0)
			item:setData("common_altas_2", arr[i].attr_icon_2, LanUtil.formateStr(390008, arr[i].show_name, tostring(arr[i].showValue)))
		end
	end
end

function Lua_HeroWeaponSkillWindow:showBuff(arr)
	local dataLen = arr:getSize()
	if dataLen > 0 and self.buffArr == nil then
		self.buffArr = Array()
	end
	local height = 0;
	local len = self.buffArr ~= nil and self.buffArr:getSize() or 0
	local maxLen = dataLen > len and dataLen or len
	local item
	for i = 1, maxLen do
		item = self.buffArr[i]
		if i > dataLen then
			if item then
				item:setEnable(false)
			end
		else
			if item == nil then
				item = Lua_WeaponSkillBuffItem.new(self.showObject)
				self.buffArr:add(item)
			else
				item:setEnable(true)
			end
			item:setData(arr[i])
			height = height + item.showHeight
		end
	end
	self.line_1:setEnable(dataLen > 0)
	return height
end










Lua_WeaponSkillBuffItem = class("Lua_WeaponSkillBuffItem", Lua_DisplayObject)
function Lua_WeaponSkillBuffItem:ctor(p)
	self:superCall("ctor", p)
end

function Lua_WeaponSkillBuffItem:buildShowItem()
	self:superCall("buildShowItem")

	self.nameText = UICreate.createLabel(self.content, nil, -185, 0, 100, 31, 22)
	self.nameText.pivotValue = 0
	self.nameText.alignmentValue = 0
	self.nameText.colorStr = Lua_ColorDefine.transColor("FFE070")
	self.nameText.horizontalOverflowValue = 1

	self.desText = UICreate.createLabel(self.content, nil, -185, -34, 375, 31, 22)
	self.desText.pivotValue = 0
	self.desText.alignmentValue = 0
	self.desText.colorStr = Lua_ColorDefine.transColor("FFFFFF")
	self.desText.horizontalOverflowValue = 0
	self.desText.verticalOverflowValue = 1
end

function Lua_WeaponSkillBuffItem:dispose()
	self:superCall("dispose")
end

function Lua_WeaponSkillBuffItem:setData(buffId)
	local config = Lua_BuffConfigData.getConfigData(buffId)
	if config == nil then
		return 0;
	end

	self.nameText.text = LanUtil.formateStr(10056, config.name)
	self.nameText:resetSize()
	self.desText.text = config.effect_des
	self.desText:resetSize()
end

function Lua_WeaponSkillBuffItem.Get:showHeight()
	return self.nameText.height + self.desText.height
end